#include <cv.h>
#include <highgui.h>

#include <string>
#include <iostream>

#include "../Descriptor.h"
#include "../Extractor.h"

void main()
{
	using namespace std;
	
	string strIm1= "image.ppm";	
	string strMask = "inputImage_a.pgm";
	string strMap = "inputImage.seg";
	string strBbox = "BoundingBoxes.txt";

	IplImage *im1 = cvLoadImage(strIm1.c_str(),-1);
	IplImage *mask = cvLoadImage(strMask.c_str(),-1);
	IplImage *map = cvLoadImage(strMap.c_str(),-1);

	Extractor ex; //extactor object

	DescriptorTypeVector dTypes; // vector of descriptors to be extracted
	dTypes.push_back(EH); // add the Edge Histogram to be extracted
	dTypes.push_back(CL); // add the Color Layout to be extracted
	Descriptor descr(dTypes); //create descriptor object containing the added types
	ex.Extract(strIm1.c_str(),NULL,descr); // extract descriptors from an image (by giving filename) globally, Descriptor passed by reference
	cout << "##### EXAMPLE 1 #####" << endl;
	descr.PrintElements(); // print the contained descriptors

	ex.Extract(im1,mask,descr);  // extract descriptors from an image' s region (by giving corresponding IplImage for image and mask)
	cout << "##### EXAMPLE 2 #####" << endl;
	descr.PrintElements(); // print the contained descriptors

	DescriptorTypeVector dTypes2; // vector of descriptors to be extracted
	dTypes2.push_back(CST);
	Descriptor descr2(dTypes2);
	descr2.SetParameters("parameters.txt"); // find parameters for each of the descriptors (CST,HT,etc..), if parameters are not set the the default values are used
	ex.Extract(strIm1.c_str(),strMask.c_str(),descr2);
	cout << "##### EXAMPLE 3 #####" << endl;
	cout << descr2.GetColorStructureDescriptor()->toString() << endl << endl; // get the color structure object and convert its data elements to a string

	DescriptorCollection descrCol(dTypes2);
	descrCol.paramtrs.ColorQuantSize = 32; // set the parameter for the Color Structure to 32 (corresponding parameters can be found in "parameters.txt"
	ex.ExtractFromMap(im1,map,descrCol); // extract descriptors from all regions of a segmentation mask (by giving corresponding IplImage for image and map)
	cout << "##### EXAMPLE 4 #####" << endl;
	descrCol.PrintElements();

	dTypes2.push_back(EH); // add Edge Histogram too to be extracted
	DescriptorCollection descrCol2(dTypes2);
	ex.ExtractFromMap(strIm1.c_str(),strMap.c_str(),descrCol2);
	descrCol2.toTxtFile("cst_regionMap.txt");  // save the descriptor vectors (concatanated vectors of all descriptors), each line containes the description for a region
	cout << "##### EXAMPLE 5 #####" << endl;
	cout << "Descriptors saved to  cst_regionMap.txt" << endl << endl;

	DescriptorTypeVector dTypes3;
	dTypes3.push_back(HT);
	DescriptorCollection descrCol3(dTypes3);
	ex.ExtractFromBBoxList(strIm1.c_str(),strBbox.c_str(),descrCol3); // extract descriptors for all bouding boxes contained in a text file (a bounding box in each line in the format: x_top_left,y_top_left,x_bot_right,y_bot_roght  )
	cout << "##### EXAMPLE 6 #####" << endl;
	cout << descrCol3.collection[3]->GetHomogeneousTextureDescriptor()->toString() << endl << endl; // print the Homogeneous Texture descriptor for the 4th bounding box

	cout << "##### EXAMPLE 7 #####" << endl;
	cout << "Distance between 1st and 2nd bounding box is : " ;
	cout <<  descrCol3.collection[0]->GetHomogeneousTextureDescriptor()->match(descrCol3.collection[1]->GetHomogeneousTextureDescriptor()) << endl; //calculate distance between 2 descriptors


}