#ifndef __CONTOURSHAPE_H__
#define __CONTOURSHAPE_H__

#include "DescriptorBase.h"


//!structure for a peak (x,y) in the curvature scale space
typedef  struct _peak
{
	unsigned short x;
	unsigned short y;
} Peak;


class __declspec (dllexport) ContourShape : public DescriptorBase
{
public:
	//!constructor
	ContourShape();

	friend std::ostream& operator << (std::ostream& os, ContourShape& s);

	//!set the number of peaks that the descriptor will contain
	void SetNoOfPeaks(unsigned char cPeaks);
    //!get the number of peaks that the descriptor contains
	unsigned char GetNoOfPeaks() const;
	//!set values for prototype curvature
	void SetPrototypeCurvature(unsigned long lC, unsigned long lE);
	//!get e(ecentricity) value for prototype curvature
	unsigned long GetPrototypeCurvatureE();
	//!get c(circularity) value for prototype curvature
	unsigned long GetPrototypeCurvatureC();
	//!set values (x,y) for a  peak
	void SetPeak(unsigned char cIndex, unsigned short iX, unsigned short iY);
	//!get a peak
	Peak GetPeak(unsigned char cIndex);


	void PrintElements();
	std::string toString();
#ifdef USEXML
	XERCES_CPP_NAMESPACE::DOMElement *toXML(XERCES_CPP_NAMESPACE::DOMDocument* doc);
	void fillDescriptor(XERCES_CPP_NAMESPACE::DOMNodeList *ndList);

#endif

	//!match descriptors and return distance
	float match(ContourShape *conShape);

	//!highest peak
	unsigned short m_iHighestPeakY;
	//!Global Curvature
	std::vector<unsigned long> m_piGlobalCurvatureVector;

};


#endif