#ifndef __DESCRIPTOR_H__
#define __DESCRIPTOR_H__

#include "DescriptorBase.h"
#include "AllDescriptors.h"
#include "Parameters.h"

class __declspec (dllexport) Descriptor 
{
public:
	//! Constructor
	Descriptor(DescriptorTypeVector descrTypeList);
	//!destructor
	~Descriptor();

	//! vector of DescriptorBase, which it can be all descriptors eg. DC, SC, etc...
	std::vector<DescriptorBase*> content;
	//! vector of DescriptorTypes which are the types of descriptors in class member content
	DescriptorTypeVector typeVector;

	//! return a pointer to the Dominant Color Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	DominantColor *GetDominantColorDescriptor();
	//! return a pointer to the Scalable Color Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	ScalableColor *GetScalableColorDescriptor();
	//! return a pointer to the Color Layout Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	ColorLayout *GetColorLayoutDescriptor();
	//! return a pointer to the Color Structure Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	ColorStructure *GetColorStructureDescriptor();	
	//! return a pointer to the  Edge Histogram Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	EdgeHistogram *GetEdgeHistogramDescriptor();
	//! return a pointer to the Homogeneous Texture Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	HomogeneousTexture *GetHomogeneousTextureDescriptor();
	//! return a pointer to the Region Shape Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	RegionShape *GetRegionShapeDescriptor();
	//! return a pointer to the Contour Shape Descriptor of the Descriptor object
	//! Returns NULL if it does not exist
	ContourShape *GetContourShapeDescriptor();

	//! Prints the element of all the descriptors
	void PrintElements();
#ifdef USEXML
	//! Saves the descriptor tree to an xml file on the disk 
	void toXML(char *xmlFilename);
	//! copy descriptor data from xml file to descriptor object
	void fromXML(char* filename);
#endif 	
	//! Saves the descriptor vectors to a txt file on the disk 
	void toTxtFile(char *txtFilename);

	//!parameters for the descriptor extraction
	Parameters paramtrs;
	//! descriptor initialisation, including initialisation of all included descriptors
	int Initialise();
	//! set the parameters from a parameter text file
	void SetParameters(char* parameterFile);

};


class __declspec (dllexport) DescriptorCollection
{
public:
	//!Constructor
	DescriptorCollection(DescriptorTypeVector descrTypeList);
	//!destructor
	~DescriptorCollection();

	//! descriptor collection initialisation, including initialisation of all included descriptors
	int Initialise(int regions);
	//! vector of descriptors
	std::vector<Descriptor*> collection;

	//! vector of DescriptorTypes which are the types of descriptors of each descriptor in the collection
	DescriptorTypeVector typeVector;

	//! sets the number of regions, which is the number of descriptors in the collection
	void SetRegions(int numberOfRegions);
	//! returns the number of regions, which is the number of descriptors in the collection
	int GetRegions(void);

	//! prints element of all descriptors in the collection
	void PrintElements();
#ifdef USEXML
	//! Saves the descriptorCollection tree to an xml file on the disk 
	void toXML(char *xmlFilename);
#endif 
     //! Saves the descriptorCollection vectors to a txt file on the disk 
	void toTxtFile(char *txtFilename);

	//!parameters for the descriptor extraction	
	Parameters paramtrs;
	//! set the parameters from a parameter text file
	void SetParameters(char* parameterFile);
private:
	//! number of regions, which is the number of descriptors in the collection
	int numberOfRegions;

};


#endif
