#ifndef __DOMINANTCOLOR_H__
#define __DOMINANTCOLOR_H__

#include "DescriptorBase.h"

//!structure of a dominant color
typedef struct _DomColor
{
  int m_Percentage;
  std::vector<int> m_ColorValue;
  std::vector<int> m_ColorVariance;
} DomColor;

class __declspec (dllexport) DominantColor  : public DescriptorBase
{
public:
	//!constuctor
	DominantColor();

	friend std::ostream& operator << (std::ostream& os, DominantColor& s);

	//!get the number of dominant colors
	int GetDominantColorsNumber();
	//!get presence of color space
	bool GetColorSpacePresent();
	//!get presence of quantization
	bool GetColorQuantizationPresent();
	//!get presence of variance
	bool GetVariancePresent();
	//!get presence of spatial coherency
	bool GetSpatialCoherencyPresent();

	//!set the number of dominant colors
	void SetDominantColorsNumber(int dc_number);
	//!Set presence of color space
	void SetColorSpacePresent(bool colspcpres);
	//!Set presence of quantization
	void SetColorQuantizationPresent(bool colquantpres);
	//!Set presence of variance
	void SetVariancePresent(bool varpres);
	//!Set presence of spatial coherency
	void SetSpatialCoherencyPresent(bool spcohpres);

	//! initialise the descriptor with the given parameters
    int Initialise(bool varPresent,bool spCoher,bool colSpacePresent,bool colQuantPres);

	void PrintElements();
	std::string toString();
#ifdef USEXML
	XERCES_CPP_NAMESPACE::DOMElement *toXML(XERCES_CPP_NAMESPACE::DOMDocument* doc);
	void fillDescriptor(XERCES_CPP_NAMESPACE::DOMNodeList *ndList);
	

#endif
	//!match descriptors and return distance
	float match(DominantColor *domCol);

	//!spatial coherency value
	int m_SpatialCoherency;
	//!vector of dominant colors
	std::vector<DomColor> m_dc;

};



#endif;